InjectableInit class

Marks a top-level function as an initializer function for configuring Get_it

Constructors

InjectableInit({List<String> generateForDir = const ['lib'], bool preferRelativeImports = true, String initializerName = r'$initGetIt', List<Type> ignoreUnregisteredTypes = const [], List<String> ignoreUnregisteredTypesInPackages = const [], bool asExtension = false, bool usesNullSafety = true})
default constructor
const

Properties

asExtension → bool
if true the init function will be generated inside of a GetIi extension defaults to false
final
generateForDir → List<String>
Only files exist in provided directories will be processed
final
hashCode → int
The hash code for this object.
no setterinherited
ignoreUnregisteredTypes → List<Type>
generator will not show warning for unregistered types included in this list
final
ignoreUnregisteredTypesInPackages → List<String>
generator will not show warning for unregistered types if import start with any string included in this list
final
initializerName → String
generated initializer name defaults to $initGetIt
final
preferRelativeImports → bool
if true relative imports will be used where possible defaults to true
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usesNullSafety → bool
weather to include null-safety suffixes to the generated code;
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited